<?php

namespace Example\Example\Http\Controllers;

use App\Http\Controllers\ResourceController as BaseController;
use Form;
use Example\Example\Http\Requests\MasterFunctionalSkillRequest;
use Example\Example\Interfaces\MasterFunctionalSkillRepositoryInterface;
use Example\Example\Models\MasterFunctionalSkill;

/**
 * Resource controller class for master_functional_skill.
 */
class MasterFunctionalSkillResourceController extends BaseController
{

    /**
     * Initialize master_functional_skill resource controller.
     *
     * @param type MasterFunctionalSkillRepositoryInterface $master_functional_skill
     *
     * @return null
     */
    public function __construct(MasterFunctionalSkillRepositoryInterface $master_functional_skill)
    {
        parent::__construct();
        $this->repository = $master_functional_skill;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Example\Example\Repositories\Criteria\MasterFunctionalSkillResourceCriteria::class);
    }

    /**
     * Display a list of master_functional_skill.
     *
     * @return Response
     */
    public function index(MasterFunctionalSkillRequest $request)
    {
        $view = $this->response->theme->listView();

        if ($this->response->typeIs('json')) {
            $function = camel_case('get-' . $view);
            return $this->repository
                ->setPresenter(\Example\Example\Repositories\Presenter\MasterFunctionalSkillPresenter::class)
                ->$function();
        }

        $master_functional_skills = $this->repository->paginate();

        return $this->response->title(trans('example::master_functional_skill.names'))
            ->view('example::master_functional_skill.index', true)
            ->data(compact('master_functional_skills'))
            ->output();
    }

    /**
     * Display master_functional_skill.
     *
     * @param Request $request
     * @param Model   $master_functional_skill
     *
     * @return Response
     */
    public function show(MasterFunctionalSkillRequest $request, MasterFunctionalSkill $master_functional_skill)
    {

        if ($master_functional_skill->exists) {
            $view = 'example::master_functional_skill.show';
        } else {
            $view = 'example::master_functional_skill.new';
        }

        return $this->response->title(trans('app.view') . ' ' . trans('example::master_functional_skill.name'))
            ->data(compact('master_functional_skill'))
            ->view($view, true)
            ->output();
    }

    /**
     * Show the form for creating a new master_functional_skill.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(MasterFunctionalSkillRequest $request)
    {

        $master_functional_skill = $this->repository->newInstance([]);
        return $this->response->title(trans('app.new') . ' ' . trans('example::master_functional_skill.name')) 
            ->view('example::master_functional_skill.create', true) 
            ->data(compact('master_functional_skill'))
            ->output();
    }

    /**
     * Create new master_functional_skill.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(MasterFunctionalSkillRequest $request)
    {
        try {
            $attributes              = $request->all();
            $attributes['user_id']   = user_id();
            $attributes['user_type'] = user_type();
            $master_functional_skill                 = $this->repository->create($attributes);

            return $this->response->message(trans('messages.success.created', ['Module' => trans('example::master_functional_skill.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('example/master_functional_skill/' . $master_functional_skill->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('/example/master_functional_skill'))
                ->redirect();
        }

    }

    /**
     * Show master_functional_skill for editing.
     *
     * @param Request $request
     * @param Model   $master_functional_skill
     *
     * @return Response
     */
    public function edit(MasterFunctionalSkillRequest $request, MasterFunctionalSkill $master_functional_skill)
    {
        return $this->response->title(trans('app.edit') . ' ' . trans('example::master_functional_skill.name'))
            ->view('example::master_functional_skill.edit', true)
            ->data(compact('master_functional_skill'))
            ->output();
    }

    /**
     * Update the master_functional_skill.
     *
     * @param Request $request
     * @param Model   $master_functional_skill
     *
     * @return Response
     */
    public function update(MasterFunctionalSkillRequest $request, MasterFunctionalSkill $master_functional_skill)
    {
        try {
            $attributes = $request->all();

            $master_functional_skill->update($attributes);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('example::master_functional_skill.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('example/master_functional_skill/' . $master_functional_skill->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('example/master_functional_skill/' . $master_functional_skill->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove the master_functional_skill.
     *
     * @param Model   $master_functional_skill
     *
     * @return Response
     */
    public function destroy(MasterFunctionalSkillRequest $request, MasterFunctionalSkill $master_functional_skill)
    {
        try {

            $master_functional_skill->delete();
            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('example::master_functional_skill.name')]))
                ->code(202)
                ->status('success')
                ->url(guard_url('example/master_functional_skill/0'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('example/master_functional_skill/' . $master_functional_skill->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove multiple master_functional_skill.
     *
     * @param Model   $master_functional_skill
     *
     * @return Response
     */
    public function delete(MasterFunctionalSkillRequest $request, $type)
    {
        try {
            $ids = hashids_decode($request->input('ids'));

            if ($type == 'purge') {
                $this->repository->purge($ids);
            } else {
                $this->repository->delete($ids);
            }

            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('example::master_functional_skill.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('example/master_functional_skill'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/example/master_functional_skill'))
                ->redirect();
        }

    }

    /**
     * Restore deleted master_functional_skills.
     *
     * @param Model   $master_functional_skill
     *
     * @return Response
     */
    public function restore(MasterFunctionalSkillRequest $request)
    {
        try {
            $ids = hashids_decode($request->input('ids'));
            $this->repository->restore($ids);

            return $this->response->message(trans('messages.success.restore', ['Module' => trans('example::master_functional_skill.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('/example/master_functional_skill'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/example/master_functional_skill/'))
                ->redirect();
        }

    }

}
