<?php

namespace Example\Example\Providers;

use Illuminate\Support\ServiceProvider;

class ExampleServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'example');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'example');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        // Bind facade
        $this->app->bind('example.example', function ($app) {
            return $this->app->make('Example\Example\Example');
        });

                // Bind MasterFunctionalSkill to repository
        $this->app->bind(
            'Example\Example\Interfaces\MasterFunctionalSkillRepositoryInterface',
            \Example\Example\Repositories\Eloquent\MasterFunctionalSkillRepository::class
        );

        $this->app->register(\Example\Example\Providers\AuthServiceProvider::class);
                $this->app->register(\Example\Example\Providers\EventServiceProvider::class);
        
        $this->app->register(\Example\Example\Providers\RouteServiceProvider::class);
                
    }

    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['example.example'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('example/example.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/example')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/example')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
